@@ -4,11 +4,10 @@ use Moose;
 use namespace::autoclean;
 
 # ABSTRACT: Manipulation of Office Open XML files
-our $VERSION = '0.172601'; # VERSION
+our $VERSION = '0.172610'; # VERSION
 
 use Archive::Zip qw( :ERROR_CODES :CONSTANTS );
 use Carp;
-use List::Util qw(any);
 use XML::LibXML;
 
 use Document::OOXML::ContentTypes;
@@ -139,16 +138,15 @@ Document::OOXML - Manipulation of Office Open XML files
 
 =head1 VERSION
 
-version 0.172601
+version 0.172610
 
 =head1 SYNOPSIS
 
     my $doc = Document::OOXML->read_document('some.docx');
 
-    $doc->search_and_replace(
-        qr/examples?/,
-        sub { return reverse(shift); }
-    );
+    $doc->replace_text('old', 'new');
+
+    $doc->save_to_file('some_other.docx');
 
 =head1 DESCRIPTION
 
